**pysimavr**

:Date: |today|
:PDF: `pysimavr.pdf <pysimavr.pdf>`_


Contents:

.. toctree::
    :maxdepth: 2

    readme
    usage
    files
    api
    
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

